@@ -13,7 +13,7 @@ use base 'Exporter';
 
 our @EXPORT = 'testauto';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 has file => (
   is => 'ro',
@@ -119,8 +119,8 @@ Test Automation, Docs Generation
 =head1 DESCRIPTION
 
 This package aims to provide, a standard for documenting Perl 5 software
-projects, a framework writing tests, and automation for validating the tests,
-documentation, and usage examples.
+projects, a framework writing tests, test automation, and documentation
+generation.
 
 =cut
 
@@ -317,6 +317,15 @@ This method returns a L<Test::Auto::Subtests> object.
   =signature $name
   =example-$number $name # [repeatable]
 
+  # [repeatable; optional]
+
+  =type $name
+  =type-library $name
+  =type-composite $name # [optional]
+  =type-parent $name # [optional]
+  =type-coercion $name # [optional]
+  =type-example-$number $name # [repeatable]
+
 The specification is designed to accommodate typical package declarations. It
 is used by the parser to provide the content used in the test automation and
 document generation.
@@ -580,6 +589,54 @@ present will include the given code example(s) with the evaluation of the
 current block. Each routine is tested and must be recognized to exist by the
 main package.
 
+=head2 types
+
+  =type Path
+
+    Path
+
+  =type-parent Path
+
+    Object
+
+  =type-library Path
+
+  Path::Types
+
+  =type-composite Path
+
+    InstanceOf["Path::Find"]
+
+  =type-coercion-1 Path
+
+    # can coerce from Str
+
+    './path/to/file'
+
+  =type-example-1 Path
+
+    require Path::Find;
+
+    Path::Find::path('./path/to/file')
+
+  =cut
+
+When developing Perl programs, or type libraries, that use L<Type::Tiny> based
+type constraints, testing and documenting custom type constraints is often
+overlooked. Describing a custom type constraint requires at least two blocks,
+i.e. C<type $name> and C<type-library $name>. While it's not strictly required,
+it's a good idea to also include at least one C<type-example-1 $name>. The
+optional C<type-parent> block should contain the name of the parent type. The
+C<type-composite> block should contain a type expression that represents the
+derived type. The C<type-coercion-$number> block is a repeatable block which
+is used to validate type coercion. The C<type-coercion-$number> block should
+contain valid Perl code and return the value to be coerced. The
+C<type-example-$number> block is a repeatable block, and it's a good idea to
+have at least one block must exist when documenting a type. The
+C<type-example-$number> block should contain valid Perl code and return a
+value. Each type is tested and must be recognized to exist within the package
+specified by the C<type-library> block.
+
 =head1 AUTOMATION
 
   $test->standard;
@@ -594,6 +651,7 @@ This is the equivalent of writing:
   $test->methods;
   $test->routines;
   $test->functions;
+  $test->types;
 
 This framework provides a set of automated subtests based on the package
 specification, but not everything can be automated so it also provides you with
@@ -657,8 +715,12 @@ L<"license file"|https://github.com/iamalnewkirk/test-auto/blob/master/LICENSE>.
 
 =head1 PROJECT
 
+L<Wiki|https://github.com/iamalnewkirk/test-auto/wiki>
+
 L<Project|https://github.com/iamalnewkirk/test-auto>
 
+L<Initiatives|https://github.com/iamalnewkirk/test-auto/projects>
+
 L<Milestones|https://github.com/iamalnewkirk/test-auto/milestones>
 
 L<Issues|https://github.com/iamalnewkirk/test-auto/issues>
