@@ -1,15 +1,15 @@
 package Test::Auto::Subtests;
 
-use Data::Object 'Class';
+use Data::Object 'Class', 'Test::Auto::Types';
 
 use Type::Registry;
 use Test::More;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 has parser => (
   is => 'ro',
-  isa => 'InstanceOf["Test::Auto::Parser"]',
+  isa => 'Parser',
   req => 1
 );
 
@@ -24,6 +24,7 @@ method standard() {
   $self->methods;
   $self->routines;
   $self->functions;
+  $self->types;
 
   return $self;
 }
@@ -35,10 +36,29 @@ method package() {
     my $package = $parser->render('name')
       or plan skip_all => "no package";
 
-    use_ok $package;
+    require_ok $package; # use_ok can't test roles
   };
 }
 
+method plugin($name) {
+  no autobox;
+
+  my $package = join '::', map ucfirst, (
+    'test', 'auto', 'plugin', $name
+  );
+
+  subtest "testing plugin ($name)", fun () {
+    use_ok $package
+      or plan skip_all => "$package not loaded";
+
+    ok $package->isa('Test::Auto::Plugin'), 'isa Test::Auto::Plugin';
+  };
+
+  my $instance = $package->new(subtests => $self);
+
+  return $instance;
+}
+
 method libraries() {
   my $parser = $self->parser;
 
@@ -170,6 +190,61 @@ method functions() {
   };
 }
 
+method types() {
+  my $parser = $self->parser;
+
+  no autobox;
+
+  subtest "testing types", fun () {
+    my $types = $parser->types;
+    plan skip_all => 'no types' if !$types || !%$types;
+
+    for my $name (sort keys %$types) {
+      subtest "testing type $name", fun () {
+        my $type = $types->{$name};
+
+        my $library = $type->{library}[0][0]
+          or plan skip_all => "no library";
+
+        use_ok $library;
+        ok $library->isa('Type::Library'), 'isa Type::Library';
+
+        my $constraint = $library->get_type($name);
+        ok $constraint, 'has constraint';
+
+        if ($constraint) {
+          ok $constraint->isa('Type::Tiny'), 'isa Type::Tiny constraint';
+
+          for my $number (sort keys %{$type->{examples}}) {
+            my $example = $type->{examples}{$number};
+            my $context = join "\n", @{$example->[0]};
+
+            subtest "testing example-$number ($name)", fun () {
+              my $tryable = $self->tryable($context)->call('evaluator');
+              my $result = $tryable->result;
+
+              ok $constraint->check($result), 'passed constraint check';
+            };
+          }
+
+          for my $number (sort keys %{$type->{coercions}}) {
+            my $coercion = $type->{coercions}{$number};
+            my $context = join "\n", @{$coercion->[0]};
+
+            subtest "testing coercion-$number ($name)", fun () {
+              my $tryable = $self->tryable($context)->call('evaluator');
+              my $result = $tryable->result;
+
+              ok $constraint->check($constraint->coerce($result)),
+                'passed constraint coercion';
+            };
+          }
+        }
+      };
+    }
+  };
+}
+
 method synopsis($callback) {
   my $parser = $self->parser;
 
@@ -192,8 +267,8 @@ method scenario($name, $callback) {
   my @content = $example ? @{$example->[0]} : ();
 
   unshift @content,
-    (map $parser->render($_),
-      (map +(/# given:\s*(\w+)/g), @content));
+    (map $parser->render(split /\s/),
+      (map +(/# given:\s*([\w\s-]+)/g), @content));
 
   my $tryable = $self->tryable(join "\n", @content);
 
@@ -565,6 +640,25 @@ package.
 
 =cut
 
+=head2 plugin
+
+  plugin(Str $name) : Object
+
+This method builds, tests, and returns a plugin object based on the name
+provided.
+
+=over 4
+
+=item plugin example #1
+
+  # given: synopsis
+
+  $subtests->plugin('ShortDescription');
+
+=back
+
+=cut
+
 =head2 registry
 
   registry() : InstanceOf["Type::Registry"]
@@ -663,6 +757,7 @@ standard subtests.
   # $self->methods;
   # $self->routines;
   # $self->functions;
+  # $self->types;
 
 =back
 
@@ -748,8 +843,12 @@ L<"license file"|https://github.com/iamalnewkirk/test-auto/blob/master/LICENSE>.
 
 =head1 PROJECT
 
+L<Wiki|https://github.com/iamalnewkirk/test-auto/wiki>
+
 L<Project|https://github.com/iamalnewkirk/test-auto>
 
+L<Initiatives|https://github.com/iamalnewkirk/test-auto/projects>
+
 L<Milestones|https://github.com/iamalnewkirk/test-auto/milestones>
 
 L<Issues|https://github.com/iamalnewkirk/test-auto/issues>
